# Roadmap

Rough roadmap for features and changes that we intend to add.

Please don't interpret this roadmap as anything but a note and memory aide.
It doesn't represent a promise or commitment of any kind.

* Create new pattern pat-form which swallows focus and inject history patterns.
* Update pat-toggle to allow toggling of other attributes/properties besides class.

Demos that need to be updated:

* Slides
* Slideshow-builder
